..
   Do not edit this .rst file directly — it’s generated programmatically.
   See doc/reference.sh.

==================================================
Module: ``quota``
==================================================

`Leer en español </es/latest/reference/quota.html>`_

- **get quota**

Get the cPanel account’s total disk quota information in megabytes.

*Example*

.. code:: sh

    $ cpanel get quota

See a sample of the JSON result data at:
https://api.docs.cpanel.net/openapi/cpanel/operation/get_quota_info/


